# 1.2.3
Updated NavTricks (fixed bug in `withParentPage`)

# 1.2.2
Updated NavTricks (dropped `NavTricks.replaceCurrentPage()`)

# 1.2.1

Updated NavTricks (bug fix)

# 1.2.0

Added `window.disable_local_reload` flag

# 1.1.1

Minor NavTricks change

# 1.1.0

Added NavTricks.js to static files.

# 1.0.0

# 0.0.0